@@ -72,7 +72,7 @@ class Serialize(object):
         ET.SubElement(authentication, 'transactionKey').text = auth.key
         
         # Set the reference ID
-        if trans.ref_id:
+        if trans.ref_id is not None:
             ET.SubElement(root, 'refId').text = trans.ref_id
         
         # Do we have a subscription ID provided?
@@ -84,11 +84,11 @@ class Serialize(object):
             subscription = ET.SubElement(root, 'subscription')
             
             # Do we have a name for this subscription?
-            if trans.name:
+            if trans.name is not None:
                 ET.SubElement(subscription, 'name').text = trans.name
             
             # Build the schedule element
-            if trans.schedule:
+            if trans.schedule is not None:
                 sched    = trans.schedule
                 
                 schedule = ET.SubElement(subscription, 'paymentSchedule')
@@ -99,22 +99,22 @@ class Serialize(object):
                 ET.SubElement(schedule, 'startDate').text = sched.start.strftime('%Y-%m-%d')
                 
                 # If a trial, build the element
-                if sched.trial_cycles:
+                if sched.trial_cycles is not None:
                     sched.cycles + sched.trial_cycles
                     ET.SubElement(schedule, 'trialOccurrences').text = str(sched.trial_cycles)
                 
                 ET.SubElement(schedule, 'totalOccurrences').text = str(sched.cycles)
                 
             # Build the charge amount element
-            if trans.amount:
+            if trans.amount is not None:
                 ET.SubElement(subscription, 'amount').text = trans.amount
                 
             # Build the trial amount
-            if trans.trial_amount:
+            if trans.trial_amount is not None:
                 ET.SubElement(subscription, 'trialAmount').text = trans.trial_amount
                 
             # Build the payment element
-            if trans.payment:
+            if trans.payment is not None:
                 if ICreditCard.providedBy(trans.payment):
                     payment = ET.SubElement(subscription, 'payment')
                     credit  = ET.SubElement(payment, 'creditCard')
@@ -122,7 +122,7 @@ class Serialize(object):
                     ET.SubElement(credit, 'cardNumber').text     = trans.payment.number
                     ET.SubElement(credit, 'expirationDate').text = trans.payment.expiration.strftime('%Y-%m')
                     
-                    if trans.payment.ccv:
+                    if trans.payment.ccv is not None:
                         ET.SubElement(credit, 'cardCode').text = trans.payment.code
                     
                 elif IBank.providedBy(trans.payment):
@@ -139,11 +139,11 @@ class Serialize(object):
             # Build any special order information
             order = False
             
-            if trans.invoice:
+            if trans.invoice is not None:
                 order = ET.SubElement(subscription, 'order')
                 ET.SubElement(order, 'invoiceNumber').text = trans.invoice
             
-            if trans.description:
+            if trans.description is not None:
                 if order is False:
                     order = ET.SubElement(subscription, 'order')
                 
@@ -152,29 +152,29 @@ class Serialize(object):
             # Build the customer and bill to elements
             customer = False
             
-            if trans.customer_id:
+            if trans.customer_id is not None:
                 customer = ET.SubElement(subscription, 'customer')
                 ET.SubElement(customer, 'id').text  = trans.customer_id
-            if trans.email:
+            if trans.email is not None:
                 if customer is False:
                     customer = ET.SubElement(subscription, 'customer')
                 
                 ET.SubElement(customer, 'email').text = trans.email
-            if trans.billing and trans.billing.phone:
+            if (trans.billing is not None) and (trans.billing.phone is not None):
                 if customer is False:
                     customer = ET.SubElement(subscription, 'customer')
                 ET.SubElement(customer, 'phoneNumber').text = trans.billing.phone
-            if trans.billing and trans.billing.fax:
+            if (trans.billing is not None) and (trans.billing.fax is not None):
                 if customer is False:
                     customer = ET.SubElement(subscription, 'customer')
                 ET.SubElement(customer, 'faxNumber').text = trans.billing.fax
             
             # Build the billing elements
-            if trans.billing:
+            if trans.billing is not None:
                 self._prototype_address(subscription, trans.billing, 'billTo')
             
             # Build the shipping elements
-            if trans.shipping:
+            if trans.shipping is not None:
                 self._prototype_address(subscription, trans.shipping, 'shipTo')
         
         return ET.tostring(root, encoding='UTF-8')
